from cryptography.fernet import Fernet

key = Fernet.generate_key()
print(key)

cipher = Fernet(key)

# ----------------------------------------------------

with open('../../my_key.txt', 'wb') as f:
    f.write(key)

text_to_secure = open('../../stih.txt', 'rb').read()
print(text_to_secure)

with open('../../my_secured_text.txt', 'wb') as f:
    f.write(cipher.encrypt(text_to_secure))

text_to_unsecure = open('../../my_secured_text.txt', 'rb').read()
print(text_to_unsecure)

with open('../../my_unsecured_text.txt', 'wb') as f:
    f.write(cipher.decrypt(text_to_unsecure))


import setuptools


with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="SecretF",
    version="1.101.2",
    author="Fedorenko Timur",
    author_email="tim.fedorenko@mail.ru",
    description="Secret File",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/HardHook/SecretF",
    classifiers=[
        "Operating System :: Microsoft :: Windows :: Windows 10",
        "Programming Language :: Python :: 3.9",
    ],
    package_dir={"": "scr"},
    packages=setuptools.find_packages(where="scr"),
)